==> endpoint-2.2.0-sources.jar: dev/hilla/internal/hotswap/HotSwapConfiguration.java <==
/*
 * Copyright 2000-2023 Vaadin Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

package dev.hilla.internal.hotswap;

import dev.hilla.EndpointCodeGenerator;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

@Configuration
public class HotSwapConfiguration {

    @Bean
    @ConfigurationProperties(prefix = "hilla.endpoint.hot-reload")
    public HotSwapConfigurationProperties hotSwapConfigurationProperties() {
        return new HotSwapConfigurationProperties();
    }

    @Bean
    EndpointHotSwapService hotSwapWatchService(
            @Autowired HotSwapConfigurationProperties configurationProperties) {
        return new PollChangedEndpointsHotSwapService(
                configurationProperties.getPollInterval());
    }

    @Bean
    HotSwapServiceInitializer hotSwapServiceInitializer(
            @Autowired EndpointHotSwapService endpointHotSwapService,
            @Autowired HotSwapConfigurationProperties configurationProperties) {
        return new HotSwapServiceInitializer(endpointHotSwapService,
                configurationProperties.isEnabled());
    }

    @Bean
    EndpointHotSwapListener endpointHotSwapListener(
            @Autowired EndpointHotSwapService endpointHotSwapService,
            EndpointCodeGenerator endpointCodeGenerator) {
        return new EndpointHotSwapListener(endpointHotSwapService,
                endpointCodeGenerator);
    }
}

==> endpoint-2.5.8-sources.jar: dev/hilla/internal/hotswap/HotSwapConfiguration.java <==
/*
 * Copyright 2000-2023 Vaadin Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

package dev.hilla.internal.hotswap;

import dev.hilla.EndpointCodeGenerator;
import dev.hilla.Hotswapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

@Configuration
public class HotSwapConfiguration {

    @Bean
    @ConfigurationProperties(prefix = "hilla.endpoint.hot-reload")
    public HotSwapConfigurationProperties hotSwapConfigurationProperties() {
        return new HotSwapConfigurationProperties();
    }

    @Bean
    EndpointHotSwapService hotSwapWatchService(
            @Autowired HotSwapConfigurationProperties configurationProperties) {
        return new PollChangedEndpointsHotSwapService(
                configurationProperties.getPollInterval());
    }

    @Bean
    HotSwapServiceInitializer hotSwapServiceInitializer(
            @Autowired EndpointHotSwapService endpointHotSwapService,
            @Autowired HotSwapConfigurationProperties configurationProperties) {
        return new HotSwapServiceInitializer(endpointHotSwapService,
                configurationProperties.isEnabled() && !Hotswapper.isInUse());
    }

    @Bean
    EndpointHotSwapListener endpointHotSwapListener(
            @Autowired EndpointHotSwapService endpointHotSwapService) {
        return new EndpointHotSwapListener(endpointHotSwapService);
    }
}
